@@ -77,22 +77,22 @@ F77_SUB(frailpred_sha_nor_mc)(int *np0, double *frailtypred, double *sig20, doub
 						int *nig0);
 						
 void 
-F77_SUB(joint)(int *nsujet0, int *ngrp, int *nstRecAux, int *strAux, int *lignedc0, int *nz0, 
+F77_SUB(joint)(int *nsujet0, int *ngrp, int *strAux, int *lignedc0, int *nz0, 
 						double *axT, double *tt00, double *tt10, int *ic0, int *groupe0, 
 						int *groupe00, int *fam0, double *tt0dc0, double *tt1dc0, int *icdc0, 
 						double *tempdc, int *icdc00, int *nva10, double *vax0, int *nva20, double *vaxdc0, 
-						double *vaxdc00, int *noVar,  int *maxit0, int *np, double *b, 
+						double *vaxdc00, int *noVar, double wtsvec0, int *maxit0, int *np, double *b, 
 						double *H_hessOut, double *HIHOut, double *resOut, double *LCV, double *x1Out, 
 						double *lamOut, double *xSu1, double *suOut, double *x2Out, 
-						double *lam2Out, double *xSu2, double *su2Out, int *typeof0,
-						int *equidistant, int *nbinterv0, int *mtaille, int *counts, 
+						double *lam2Out, double *xSu2, double *su2Out, int *typeofequidist,
+						int *nbinterv0, int *mtaille, int *counts, 
 						int *IerIstop, double *paraweib, double *MartinGales, 
 						double *linearpred, double *linearpreddc, double *ziOut, 
 						double *time, double *timedc, double *linearpredG, int *typeJoint0, 
 						int *intcens0, int *indices0, double *ttU0, int *ordretmp, int *initialize,
 						int *logNormal0, int *paratps, int *filtretps0, double *BetaTpsMat, 
 						double *BetaTpsMatDc, double *EPS);	
-						
+				
 void 
 F77_SUB(joint_longi)(int *nsujet0, int *nsujety0, int *ng0, int *nz0, double *k0, 
 						double *tt00, double *tt10, int *ic0, int *groupe0, 
